==> nextcloud-27.1.5.tgz: nextcloud/apps/logreader/l10n/uk.js <==
OC.L10N.register(
    "logreader",
    {
    "Logging" : "Журналювання",
    "Errors in the log" : "Помилки в журналі",
    "No errors in the logs since %s" : "Жодних помилок в журналі, починаючи з %s",
    "_%n error in the logs since %s_::_%n errors in the logs since %s_" : [" %n помилка в журналах, починаючи з %s","%n помилки в журналах, починаючи з %s","%nпомилок в журналах, починаючи з %s"," %nпомилок в журналах, починаючи з %s"],
    "_%n warning in the logs since %s_::_%n warnings in the logs since %s_" : ["%n попередження в журналах, починаючи з %s","%nпопередження в журналах, починаючи з %s","%n попереджень в журналах, починаючи з %s","%n попереджень в журналах, починаючи з %s"],
    "Log Reader" : "Читач журналів",
    "A log reader for Nextcloud" : "Програма для читання журналів для Nextcloud",
    "Log reader for Nextcloud" : "Читач журналів для Nextcloud",
    "Log reader" : "Перегляд журналу",
    "Open log reader settings" : "Відкрити налаштування перегляду журнау",
    "Log reader settings" : "Налаштування перегляду журналу",
    "Currently the log file {file} is shown" : "Наразі показується файл журналу {file}",
    "Show server log" : "Показати журнал сервера",
    "Live view is disabled" : "Перегляд наживо вимкнено",
    "No log file" : "Відсутній файл журналу",
    "File-based logging must be enabled to access logs from the Web UI." : "Щоби переглядати журнал у вебзастосунку, потрібно увімкнути журналювання зі збереженням у окремий файл.",
    "If you feel this is an error, please verify {setting} in your {config} and check the Nextcloud Administration Manual." : "Якщо ви вважаєте, що це помилка, будь ласка, перевірте {setting} у вашому {config}, а також перегляньте посібник з адміністрування Nextcloud.",
    "Level" : "Рівень",
    "App" : "Застосунок",
    "No app in context" : "Нема застосунку у вмісті",
    "Time" : "Час",
    "Copy raw entry" : "Копіювати неформатований запис",
    "Copy formatted entry" : "Копіювати форматований запис",
    "Hide exception details" : "Приховати деталі винятку",
    "View exception details" : "Показувати деталі винятку",
    "Raw log entry" : "Неформатований запис журналу",
    "Log entry successfully copied" : "Запис журналу скопійовано",
    "Search log entries" : "Пошук в журналі",
    "Caused by {exception}" : "Викликано {exception}",
    "Line {line}" : "Рядок {line}",
    "Filter log levels" : "Фільтр рівня журналу",
    "Set log level" : "Встановити рівень журналювання",
    "Time format" : "Формат часу",
    "Live view" : "Наживо",
    "Download/Upload logs" : "Журнал звантаження/завантаження",
    "Download logs" : "Звантажити журнали",
    "Show local log file" : "Показати файл журналу на пристрої",
    "Upload local log file to be displayed" : "Завантажити файл журналу на пристрої для показу",
    "Raw data" : "Неформатовані дані",
    "Local time" : "Місцевий час",
    "UTC time" : "Час UTC",
    "Time format used for displaying the timestamp" : "Формат часу для показу часового відбитку",
    "(Local log files only support the \"raw\" time format)" : "(Файли журналів на пристрої підтримують тільки неформатований формат часу)",
    "Could not change date time format." : "Не вдалося змінити формат часу.",
    "Polling is disabled because server is not configured to log to file" : "Надсилання запитів вимкнено, оскільки сервер не налаштовано зберігати журнал у файл.",
    "Polling (live view)" : "Надсилання запитів (перегляд наживо)",
    "Could not change live view setting." : "Не вдалося змінити налаштування перегляду наживо.",
    "Filter logging levels" : "Фільтр рівнів журналювання",
    "Could not set logging levels to show" : "Не вдалося встановити рівні показу журналу",
    "Set backend loglevel" : "Встановити рівень журналювання для бекенду",
    "Could not set logging level" : "Не вдалося встановити рівень журналювання",
    "Application" : "Застосунок",
    "Message" : "Повідомлення",
    "Log entry actions" : "Дії із записами журналу",
    "Loading older log entries" : "Завантаження попередніх записів журналу",
    "No older log entries available" : "Відсутні попередні записи журналу",
    "Collapse row" : "Приховати рядки",
    "Expand row" : "Показати рядки",
    "Show details" : "Показати деталі",
    "Debug" : "Зневадження",
    "Info" : "Info",
    "Warning" : "Попередження",
    "Error" : "Помилка",
    "Fatal" : "Фатальний",
    "Could not load log entries" : "Не вдалося завантажити записи журналу",
    "Could not fetch new log entries (server unavailable)" : "Не вдалося отримати нові записи журналу (сервер не відповідає)",
    "Could not fetch new entries" : "Не вдалося отримати нові записи журналу",
    "Could not copy to clipboard, please copy manually:" : "Не вдалося скопіювати до буферу обміну. Будь ласка, скопіюйте вручну:",
    "\tfrom {address} by {user} at {time}\n" : "\tвід {address} користувач {user} о {time}\n",
    "Error parsing log" : "Помилка аналізу журналу",
    "Caused by " : "Спричинений",
    "Copy" : "Копіювати",
    "Copy raw" : "Скопіюйте raw",
    "Copy formatted" : "Копіювати відформатовано",
    "No server logs" : "Немає журналів сервера",
    "One or more entries are hidden by the log level filter" : "Один або кілька записів приховано фільтром рівня журналу",
    "Everything is working fine" : "Все працює добре",
    "Load log file" : "Завантажити файл журналу",
    "Invalid log file" : "Недійсний файл журналу",
    "Log levels" : "Рівні журналу",
    "Log content" : "Вміст журналу",
    "Live update" : "В реальному часі",
    "line {line}" : "рядок {line}",
    "Download / Upload logs" : "Звантажити/завантажити журнал"
},
"nplurals=4; plural=(n % 1 == 0 && n % 10 == 1 && n % 100 != 11 ? 0 : n % 1 == 0 && n % 10 >= 2 && n % 10 <= 4 && (n % 100 < 12 || n % 100 > 14) ? 1 : n % 1 == 0 && (n % 10 ==0 || (n % 10 >=5 && n % 10 <=9) || (n % 100 >=11 && n % 100 <=14 )) ? 2: 3);");

==> nextcloud-28.0.3.tgz: nextcloud/apps/logreader/l10n/uk.js <==
OC.L10N.register(
    "logreader",
    {
    "Logging" : "Журналювання",
    "Errors in the log" : "Помилки в журналі",
    "No errors in the logs since %s" : "Жодних помилок в журналі, починаючи з %s",
    "_%n error in the logs since %s_::_%n errors in the logs since %s_" : [" %n помилка в журналах, починаючи з %s","%n помилки в журналах, починаючи з %s","%nпомилок в журналах, починаючи з %s"," %n помилок в журналах, починаючи з %s"],
    "_%n warning in the logs since %s_::_%n warnings in the logs since %s_" : ["%n попередження в журналах, починаючи з %s","%nпопередження в журналах, починаючи з %s","%n попереджень в журналах, починаючи з %s","%n попереджень в журналах, починаючи з %s"],
    "Log Reader" : "Читач журналів",
    "A log reader for Nextcloud" : "Застосунок для перегляду системних журналів для Nextcloud",
    "Log reader for Nextcloud" : "Читач журналів для Nextcloud",
    "Log reader" : "Перегляд журналу",
    "Open log reader settings" : "Відкрити налаштування перегляду журнау",
    "Log reader settings" : "Налаштування перегляду журналу",
    "Currently the log file {file} is shown" : "Наразі показується файл журналу {file}",
    "Show server log" : "Показати журнал сервера",
    "Live view is disabled" : "Перегляд наживо вимкнено",
    "No log file" : "Відсутній файл журналу",
    "File-based logging must be enabled to access logs from the Web UI." : "Щоби переглядати журнал у вебзастосунку, потрібно увімкнути журналювання зі збереженням у окремий файл.",
    "If you feel this is an error, please verify {setting} in your {config} and check the Nextcloud Administration Manual." : "Якщо ви вважаєте, що це помилка, будь ласка, перевірте {setting} у вашому {config}, а також перегляньте посібник з адміністрування Nextcloud.",
    "Level" : "Рівень",
    "App" : "Застосунок",
    "No app in context" : "Нема застосунку у вмісті",
    "Time" : "Час",
    "Copy raw entry" : "Копіювати невідформатований запис",
    "Copy formatted entry" : "Копіювати форматований запис",
    "Hide exception details" : "Приховати деталі винятку",
    "View exception details" : "Показувати деталі винятку",
    "Raw log entry" : "Невідформатований запис журналу",
    "Log entry successfully copied" : "Запис журналу скопійовано",
    "Search log entries" : "Пошук в журналі",
    "Caused by {exception}" : "Викликано {exception}",
    "Line {line}" : "Рядок {line}",
    "Filter log levels" : "Фільтр рівня журналу",
    "Set log level" : "Встановити рівень журналювання",
    "Time format" : "Формат часу",
    "Live view" : "Наживо",
    "Download/Upload logs" : "Журнал звантаження/завантаження",
    "You can also show log entries copied from your clipboard by pasting them on the log view using: {keyboardShortcut}" : "Ви також можете переглянути записи журналу, для цього скопіюйте їх з буфера обміну та вставте у журналі за допомогою: {keyboardShortcut}",
    "Download logs" : "Звантажити журнали",
    "Show local log file" : "Показати файл журналу на пристрої",
    "Upload local log file to be displayed" : "Завантажити файл журналу на пристрої для показу",
    "Ctrl" : "Ctrl",
    "Could not parse local log file" : "Не вдалося розібрати локальний файл журналу",
    "Raw data" : "Невідформатовані дані",
    "Local time" : "Місцевий час",
    "UTC time" : "Час UTC",
    "Time format used for displaying the timestamp" : "Формат часу для показу часового відбитку",
    "(Local log files only support the \"raw\" time format)" : "(Файли журналів на пристрої підтримують тільки невідформатований формат часу)",
    "Could not change date time format." : "Не вдалося змінити формат часу.",
    "Polling is disabled because server is not configured to log to file" : "Надсилання запитів вимкнено, оскільки сервер не налаштовано зберігати журнал у файл.",
    "Polling (live view)" : "Надсилання запитів (перегляд наживо)",
    "Could not change live view setting." : "Не вдалося змінити налаштування перегляду наживо.",
    "Filter logging levels" : "Фільтр рівнів журналювання",
    "Could not set logging levels to show" : "Не вдалося встановити рівні показу журналу",
    "Set backend loglevel" : "Встановити рівень журналювання для бекенду",
    "Could not set logging level" : "Не вдалося встановити рівень журналювання",
    "Application" : "Застосунок",
    "Message" : "Повідомлення",
    "Log entry actions" : "Дії із записами журналу",
    "Loading older log entries" : "Завантаження попередніх записів журналу",
    "No older log entries available" : "Відсутні попередні записи журналу",
    "Collapse row" : "Приховати рядки",
    "Expand row" : "Показати рядки",
    "Show details" : "Показати деталі",
    "Debug" : "Зневадження",
    "Info" : "Info",
    "Warning" : "Попередження",
    "Error" : "Помилка",
    "Fatal" : "Фатальний",
    "Could not load log entries" : "Не вдалося завантажити записи журналу",
    "Clipboard" : "Буфер обміну",
    "Could not parse clipboard content" : "Не вдалося отримати вміст буфера обміну",
    "Could not fetch new log entries (server unavailable)" : "Не вдалося отримати нові записи журналу (сервер не відповідає)",
    "Could not fetch new entries" : "Не вдалося отримати нові записи журналу",
    "Could not copy to clipboard, please copy manually:" : "Не вдалося скопіювати до буферу обміну. Будь ласка, скопіюйте вручну:",
    "\tfrom {address} by {user} at {time}\n" : "\tвід {address} користувач {user} о {time}\n",
    "Error parsing log" : "Помилка аналізу журналу",
    "Caused by " : "Спричинений",
    "Copy" : "Копіювати",
    "Copy raw" : "Копіювати невідформатовано",
    "Copy formatted" : "Копіювати відформатовано",
    "No server logs" : "Немає журналів сервера",
    "One or more entries are hidden by the log level filter" : "Один або кілька записів приховано фільтром рівня журналу",
    "Everything is working fine" : "Все працює добре",
    "Load log file" : "Завантажити файл журналу",
    "Invalid log file" : "Недійсний файл журналу",
    "Log levels" : "Рівні журналу",
    "Log content" : "Вміст журналу",
    "Live update" : "В реальному часі",
    "line {line}" : "рядок {line}",
    "Download / Upload logs" : "Звантажити/завантажити журнал"
},
"nplurals=4; plural=(n % 1 == 0 && n % 10 == 1 && n % 100 != 11 ? 0 : n % 1 == 0 && n % 10 >= 2 && n % 10 <= 4 && (n % 100 < 12 || n % 100 > 14) ? 1 : n % 1 == 0 && (n % 10 ==0 || (n % 10 >=5 && n % 10 <=9) || (n % 100 >=11 && n % 100 <=14 )) ? 2: 3);");
